LavueController Tango Class User‘s Guide

|  |  |  |  |  |  |  |  |  |

## LavueController Tango Python Class

Contents :

- Description
- Properties
- Commands
  - State
  - Status
- Attributes
  - BeamCenterX
  - BeamCenterY
  - DetectorDistance
  - DetectorROIs
  - DetectorROIsValues
  - Energy
  - DetectorROIsParams
  - LavueState
  - PixelSizeX
  - PixelSizeY
  - ToolResults
  - ScalarDynamicAttr (dynamic)
  - SpectrumDynamicAttr (dynamic)
  - ROIsDynamicAttr (dynamic)
- States

LavueController Class Identification : | LavueController Class Inheritance :
Contact | : at desy.de - jan.kotanski
Class Family | : SoftwareSystem
Platform | : All Platforms
Bus | : Not Applicable
Manufacturer | : none
Manufacturer ref. | :
| Tango::DeviceImpl LavueController

LavueController Class Description :

tango server to change lavue setting in real time

LavueController Properties :
There is no class properties

Device Properties
Name | Description | Type | Default Value
DynamicROIs | create dynamically Attributes for ROIs aliases with their bounds | boolean | True
DynamicROIsValues | create dynamically Attributes for ROIs aliases with their sums | boolean | True
ROIAttributesNames | fixed ROI attributes names, They should ends with ROI, Sum or Sums | String[] | none

LavueController Class Commands
Name | Input type | Output type | Level | Description
State | DEV_VOID | DEV_STATE | OPERATOR | This command gets the device state (stored in its device_state data member) and returns it to the caller.
Status | DEV_VOID | CONST_DEV_STRING | OPERATOR | This command gets the device status (stored in its device_status data member) and returns it to the caller.

Command State :

This command gets the device state (stored in its device_state data member) and returns it to the caller.

State Definition
Input Argument | Tango::DEV_VOID | none
Output Argument | Tango::DEV_STATE | Device state
DisplayLevel | OPERATOR | ..
Inherited | true | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command allowed for | All states | ..

Command Status :

This command gets the device status (stored in its device_status data member) and returns it to the caller.

Status Definition
Input Argument | Tango::DEV_VOID | none
Output Argument | Tango::CONST_DEV_STRING | Device status
DisplayLevel | OPERATOR | ..
Inherited | true | ..
Abstract | false | ..
Polling Period | Not polled | ..
Command allowed for | All states | ..

LavueController Class Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
BeamCenterX | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
BeamCenterY | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
DetectorDistance | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
DetectorROIs | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | json dictionary with detector ROIs, e.g. {\"pilatusroi1\": [[26, 15, 232, 65]], \"lambdarois\": [[54, 78, 102, 204], [10, 20, 40, 50]]}
DetectorROIsValues | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | json dictionary with detector ROIs values, e.g. {\"pilatusroi1\": [26.3], \"lambdarois\": [54.3, 434.30]]}
Energy | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR |
DetectorROIsParams | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | OPERATOR | json dictionary with detector ROIs parameters, e.g. {\"transpose\": False, \"flip-lr\": True, \"flip-ud\": False}
LavueState | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | json dictionary with lavue state configuration, e.g. {\``source\``: \``hidra\``, \``configuration\``: \``hasodet.desy.de\``}
PixelSizeX | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR | pixel x- size in micrometers
PixelSizeY | false | false | Scalar | READ_WRITE | Tango::DEV_DOUBLE | OPERATOR | pixel y- size in micrometers
ToolResults | false | false | Scalar | READ_WRITE | Tango::DEV_STRING | EXPERT | json dictionary with tool results

LavueController Class Dynamic Attributes
Name | Inherited | Abstract | Attr. type | R/W type | Data type | Level | Description
ScalarDynamicAttr | false | false | Scalar | READ | Tango::DEV_DOUBLE | OPERATOR |
SpectrumDynamicAttr | false | false | Spectrum | READ | Tango::DEV_DOUBLE | OPERATOR |
ROIsDynamicAttr | false | false | Spectrum | READ | Tango::DEV_DOUBLE | OPERATOR |

Attribute BeamCenterX :

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | beam center x
unit | pixels
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute BeamCenterY :

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | beam center y
unit | pixels
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute DetectorDistance :

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | detector distance
unit | mm
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute DetectorROIs :

json dictionary with detector ROIs, e.g. {\"pilatusroi1\": [[26, 15, 232, 65]], \"lambdarois\": [[54, 78, 102, 204], [10, 20, 40, 50]]}

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | detector ROIs
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute DetectorROIsValues :

json dictionary with detector ROIs values, e.g. {\"pilatusroi1\": [26.3], \"lambdarois\": [54.3, 434.30]]}

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | detector ROIs values
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute Energy :

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | beam energy
unit | eV
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute DetectorROIsParams :

json dictionary with detector ROIs parameters, e.g. {\"transpose\": False, \"flip-lr\": True, \"flip-ud\": False}

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | detector ROIs parameters
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute LavueState :

json dictionary with lavue state configuration, e.g. {\``source\``: \``hidra\``, \``configuration\``: \``hasodet.desy.de\``}

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | Lavue State
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute PixelSizeX :

pixel x- size in micrometers

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | pixel x-size
unit | um
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute PixelSizeY :

pixel y- size in micrometers

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | pixel y-size
unit | um
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | 0.0001
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Attribute ToolResults :

json dictionary with tool results

Attribute Definition
Attribute Type | Scalar
R/W Type | READ_WRITE
Data Type | Tango::DEV_STRING
Display Level | EXPERT
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | true
Write hardware at init. | true
Read allowed for | All states
Write allowed for | All states
Attribute Properties
label | tool results
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | true
Criteria checked by TANGO | false
Push Archive event by user code | false
Push DataReady event by user code | false

Dynamic attribute ScalarDynamicAttr :

Attribute Definition
Attribute Type | Scalar
R/W Type | READ
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Attribute Properties
label |
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Dynamic attribute SpectrumDynamicAttr :

Attribute Definition
Attribute Type | Spectrum ( 4096 )
R/W Type | READ
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Attribute Properties
label |
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

Dynamic attribute ROIsDynamicAttr :

Attribute Definition
Attribute Type | Spectrum ( 4096 )
R/W Type | READ
Data Type | Tango::DEV_DOUBLE
Display Level | OPERATOR
Inherited | false
Abstract | false
Polling Period | Not polled
Memorized | Not set
Read allowed for | All states
Attribute Properties
label |
unit |
standard unit |
display unit |
format |
max_value |
min_value |
max_alarm |
min_alarm |
max_warning |
min_warning |
delta_time |
delta_val |
Attribute Event Criteria
Periodic | Not set
Relative Change | Not set
Absolute Change | Not set
Archive Periodic | Not set
Archive Relative Change | Not set
Archive Absolute Change | Not set
Push Change event by user code | false
Push Archive event by user code | false
Push DataReady event by user code | false

LavueController Class States
Name | Description
ON |
OFF |